package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.DSAParameter;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.crypto.params.DSAPrivateKeyParameters;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import java.security.interfaces.DSAParams;
import java.security.interfaces.DSAPrivateKey;
import java.security.spec.DSAParameterSpec;
import java.security.spec.DSAPrivateKeySpec;
import java.util.Enumeration;

public class JDKDSAPrivateKey implements DSAPrivateKey, PKCS12BagAttributeCarrier {
   private static final long serialVersionUID = -4677259546958385734L;
   BigInteger x;
   DSAParams dsaSpec;
   private PKCS12BagAttributeCarrierImpl attrCarrier;

   protected JDKDSAPrivateKey() {
      JDKDSAPrivateKey var10000 = this;
      super();
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JDKDSAPrivateKey(DSAPrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = key.getX();
      this.dsaSpec = key.getParams();
   }

   JDKDSAPrivateKey(DSAPrivateKeySpec spec) {
      JDKDSAPrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = spec.getX();
      DSAPrivateKeySpec var10003 = spec;
      BigInteger var3 = spec.getP();
      BigInteger spec1 = spec.getQ();
      BigInteger var2 = var10003.getG();
      var10000.dsaSpec = new DSAParameterSpec(var3, spec1, var2);
   }

   JDKDSAPrivateKey(PrivateKeyInfo info) {
      JDKDSAPrivateKey var10000 = this;
      JDKDSAPrivateKey var10001 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      DSAParameter var3;
      var3 = new DSAParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());
      var10001.x = ((DERInteger)info.getPrivateKey()).getValue();
      DSAParameter var10003 = var3;
      DSAParameter var10004 = var3;
      BigInteger var4 = var3.getP();
      BigInteger info1 = var10004.getQ();
      BigInteger var2 = var10003.getG();
      var10000.dsaSpec = new DSAParameterSpec(var4, info1, var2);
   }

   JDKDSAPrivateKey(DSAPrivateKeyParameters params) {
      JDKDSAPrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = params.getX();
      BigInteger var10003 = params.getParameters().getP();
      BigInteger var2 = params.getParameters().getQ();
      var10000.dsaSpec = new DSAParameterSpec(var10003, var2, params.getParameters().getG());
   }

   private void readObject(ObjectInputStream in) {
      this.x = (BigInteger)in.readObject();
      BigInteger var2;
      this.dsaSpec = new DSAParameterSpec(var2 = (BigInteger)in.readObject(), var2, (BigInteger)in.readObject());
      PKCS12BagAttributeCarrierImpl var3;
      PKCS12BagAttributeCarrierImpl var10000 = var3 = new PKCS12BagAttributeCarrierImpl;
      var3.<init>();
      this.attrCarrier = var3;
      var10000.readObject(in);
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.x);
      out.writeObject(this.dsaSpec.getP());
      out.writeObject(this.dsaSpec.getQ());
      out.writeObject(this.dsaSpec.getG());
      this.attrCarrier.writeObject(out);
   }

   public String getAlgorithm() {
      return "DSA";
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      DERObjectIdentifier var10004 = X9ObjectIdentifiers.id_dsa;
      BigInteger var10007 = this.dsaSpec.getP();
      BigInteger var1 = this.dsaSpec.getQ();
      return (new PrivateKeyInfo(new AlgorithmIdentifier(var10004, (new DSAParameter(var10007, var1, this.dsaSpec.getG())).getDERObject()), new DERInteger(this.getX()))).getDEREncoded();
   }

   public DSAParams getParams() {
      return this.dsaSpec;
   }

   public BigInteger getX() {
      return this.x;
   }

   public boolean equals(Object o) {
      if (!(o instanceof DSAPrivateKey)) {
         return false;
      } else {
         DSAPrivateKey o1 = (DSAPrivateKey)o;
         return this.getX().equals(o1.getX()) && this.getParams().getG().equals(o1.getParams().getG()) && this.getParams().getP().equals(o1.getParams().getP()) && this.getParams().getQ().equals(o1.getParams().getQ());
      }
   }

   public int hashCode() {
      return this.getX().hashCode() ^ this.getParams().getG().hashCode() ^ this.getParams().getP().hashCode() ^ this.getParams().getQ().hashCode();
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }
}
